@@ -1,5 +1,5 @@
 #!/bin/sh
-# Copyright 2005-2016 ECMWF.
+# Copyright 2005-2017 ECMWF.
 #
 # This software is licensed under the terms of the Apache Licence Version 2.0
 # which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -9,4 +9,4 @@
 
 . ./include.sh
 
-${examples_dir}f_count_messages > /dev/null
+${examples_dir}grib_api_f_count_messages > /dev/null
