@@ -1,5 +1,5 @@
 /*
- * Copyright 2005-2016 ECMWF.
+ * Copyright 2005-2017 ECMWF.
  *
  * This software is licensed under the terms of the Apache Licence Version 2.0
  * which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
@@ -599,7 +599,7 @@ static int pack_long(grib_accessor* a, const long* val, size_t *len)
 {
     char buff[100];
     size_t bufflen=100;
-    char sval[100];
+    char sval[100] = {0};
     char* p=sval;
     size_t svallen=100;
     grib_accessor_g1step_range* self = (grib_accessor_g1step_range*)a;
