@@ -131,60 +131,63 @@ static void init_class(grib_accessor_class* c)
 
 static void init(grib_accessor* a,const long l, grib_arguments* args)
 {
-  int n=0;
-  grib_accessor_offset_values* self= (grib_accessor_offset_values*)a;
-  self->values=grib_arguments_get_name(a->parent->h,args,n++);
-  self->missingValue=grib_arguments_get_name(a->parent->h,args,n++);
-  a->flags |= GRIB_ACCESSOR_FLAG_FUNCTION;
-  a->length=0;
+    int n=0;
+    grib_accessor_offset_values* self= (grib_accessor_offset_values*)a;
+    self->values=grib_arguments_get_name(a->parent->h,args,n++);
+    self->missingValue=grib_arguments_get_name(a->parent->h,args,n++);
+    a->flags |= GRIB_ACCESSOR_FLAG_FUNCTION;
+    a->length=0;
 }
 
 static int  unpack_double(grib_accessor* a, double* val, size_t *len)
 {
-  int ret=0;
-  *val=0;
-  *len =1;
-  return ret;
+    int ret=0;
+    *val=0;
+    *len =1;
+    return ret;
 }
 
 static int pack_double(grib_accessor* a, const double* val, size_t *len)
 {
-  double* values=NULL;
-  size_t size=0;
-  double missingValue=0;
-  int ret=0,i=0;
-  grib_accessor_offset_values* self= (grib_accessor_offset_values*)a;
-  grib_context* c=a->parent->h->context;
-  grib_handle* h=a->parent->h;
+    double* values=NULL;
+    size_t size=0;
+    double missingValue=0;
+    long missingValuesPresent = 0;
+    int ret=0,i=0;
+    grib_accessor_offset_values* self= (grib_accessor_offset_values*)a;
+    grib_context* c=a->parent->h->context;
+    grib_handle* h=a->parent->h;
 
-  if (*val==0) return GRIB_SUCCESS;
+    if (*val==0) return GRIB_SUCCESS;
 
-  if((ret = grib_get_double_internal(h,self->missingValue,&missingValue))
-       != GRIB_SUCCESS) {
+    if((ret = grib_get_double_internal(h,self->missingValue,&missingValue)) != GRIB_SUCCESS) {
         return ret;
-  }
+    }
+    if((ret=grib_get_long_internal(h,"missingValuesPresent",&missingValuesPresent)) != GRIB_SUCCESS) {
+        return ret;
+    }
 
-  if ( (ret=grib_get_size(h,self->values,&size)) != GRIB_SUCCESS) return ret;
+    if ( (ret=grib_get_size(h,self->values,&size)) != GRIB_SUCCESS) return ret;
 
-  values=(double*)grib_context_malloc(c,size*sizeof(double));
-  if (!values) return GRIB_OUT_OF_MEMORY;
+    values=(double*)grib_context_malloc(c,size*sizeof(double));
+    if (!values) return GRIB_OUT_OF_MEMORY;
 
-  if((ret = grib_get_double_array_internal(h,self->values,values,&size))
-       != GRIB_SUCCESS) {
+    if((ret = grib_get_double_array_internal(h,self->values,values,&size)) != GRIB_SUCCESS) {
         grib_context_free(c,values);
         return ret;
-  }
+    }
 
-  for (i=0;i<size;i++)
-    if (values[i]!=missingValue) values[i]+=*val;
+    for (i=0;i<size;i++) {
+        if (missingValuesPresent) {
+            if (values[i]!=missingValue) values[i]+=*val;
+        } else {
+            values[i]+=*val;
+        }
+    }
 
+    if((ret = grib_set_double_array_internal(h, self->values,values,size)) != GRIB_SUCCESS) return ret;
 
-  if((ret = grib_set_double_array_internal(h, self->values,values,size))
-      != GRIB_SUCCESS) return ret;
+    grib_context_free(c,values);
 
-  grib_context_free(c,values);
-
-  return GRIB_SUCCESS;
+    return GRIB_SUCCESS;
 }
-
-
