@@ -113,7 +113,7 @@ static int next(grib_iterator* i, double *lat, double *lon, double *val)
 
 static int init(grib_iterator* iter,grib_handle* h,grib_arguments* args)
 {
-    int i, j, ret=0;
+    int i, j, err=0;
     double *lats, *lons; /* the lat/lon arrays to be populated */
     long nx,ny,iScansNegatively,jScansPositively,jPointsAreConsecutive,alternativeRowScanning;
     double LoVInDegrees,LaDInDegrees,Latin1InDegrees,Latin2InDegrees,latFirstInDegrees,
@@ -141,41 +141,41 @@ static int init(grib_iterator* iter,grib_handle* h,grib_arguments* args)
     const char* sjPointsAreConsecutive   = grib_arguments_get_name(h,args,self->carg++);
     const char* salternativeRowScanning  = grib_arguments_get_name(h,args,self->carg++);
 
-    if((ret = grib_get_long_internal(h, snx,&nx)) != GRIB_SUCCESS)
-        return ret;
-    if((ret = grib_get_long_internal(h, sny,&ny)) != GRIB_SUCCESS)
-        return ret;
+    if((err = grib_get_long_internal(h, snx,&nx)) != GRIB_SUCCESS)
+        return err;
+    if((err = grib_get_long_internal(h, sny,&ny)) != GRIB_SUCCESS)
+        return err;
 
     if (iter->nv!=nx*ny) {
         grib_context_log(h->context,GRIB_LOG_ERROR,"Wrong number of points (%ld!=%ldx%ld)",iter->nv,nx,ny);
         return GRIB_WRONG_GRID;
     }
-    if((ret = grib_get_double_internal(h, sradius,&radius)) != GRIB_SUCCESS)
-        return ret;
-    if((ret = grib_get_double_internal(h, sLoVInDegrees, &LoVInDegrees))!=GRIB_SUCCESS)
-        return ret;
-    if((ret = grib_get_double_internal(h, sLaDInDegrees, &LaDInDegrees))!=GRIB_SUCCESS)
-        return ret;
-    if((ret = grib_get_double_internal(h, sLatin1InDegrees, &Latin1InDegrees))!=GRIB_SUCCESS)
-        return ret;
-    if((ret = grib_get_double_internal(h, sLatin2InDegrees, &Latin2InDegrees))!=GRIB_SUCCESS)
-        return ret;
-    if((ret = grib_get_double_internal(h, slatFirstInDegrees,&latFirstInDegrees)) !=GRIB_SUCCESS)
-        return ret;
-    if((ret = grib_get_double_internal(h, slonFirstInDegrees,&lonFirstInDegrees)) !=GRIB_SUCCESS)
-        return ret;
-    if((ret = grib_get_double_internal(h, sDx,&Dx)) !=GRIB_SUCCESS)
-        return ret;
-    if((ret = grib_get_double_internal(h, sDy,&Dy)) !=GRIB_SUCCESS)
-        return ret;
-    if((ret = grib_get_long_internal(h, sjPointsAreConsecutive,&jPointsAreConsecutive)) !=GRIB_SUCCESS)
-        return ret;
-    if((ret = grib_get_long_internal(h, sjScansPositively,&jScansPositively)) !=GRIB_SUCCESS)
-        return ret;
-    if((ret = grib_get_long_internal(h, siScansNegatively,&iScansNegatively)) !=GRIB_SUCCESS)
-        return ret;
-    if((ret = grib_get_long_internal(h, salternativeRowScanning,&alternativeRowScanning)) !=GRIB_SUCCESS)
-        return ret;
+    if((err = grib_get_double_internal(h, sradius,&radius)) != GRIB_SUCCESS)
+        return err;
+    if((err = grib_get_double_internal(h, sLoVInDegrees, &LoVInDegrees))!=GRIB_SUCCESS)
+        return err;
+    if((err = grib_get_double_internal(h, sLaDInDegrees, &LaDInDegrees))!=GRIB_SUCCESS)
+        return err;
+    if((err = grib_get_double_internal(h, sLatin1InDegrees, &Latin1InDegrees))!=GRIB_SUCCESS)
+        return err;
+    if((err = grib_get_double_internal(h, sLatin2InDegrees, &Latin2InDegrees))!=GRIB_SUCCESS)
+        return err;
+    if((err = grib_get_double_internal(h, slatFirstInDegrees,&latFirstInDegrees)) !=GRIB_SUCCESS)
+        return err;
+    if((err = grib_get_double_internal(h, slonFirstInDegrees,&lonFirstInDegrees)) !=GRIB_SUCCESS)
+        return err;
+    if((err = grib_get_double_internal(h, sDx,&Dx)) !=GRIB_SUCCESS)
+        return err;
+    if((err = grib_get_double_internal(h, sDy,&Dy)) !=GRIB_SUCCESS)
+        return err;
+    if((err = grib_get_long_internal(h, sjPointsAreConsecutive,&jPointsAreConsecutive)) !=GRIB_SUCCESS)
+        return err;
+    if((err = grib_get_long_internal(h, sjScansPositively,&jScansPositively)) !=GRIB_SUCCESS)
+        return err;
+    if((err = grib_get_long_internal(h, siScansNegatively,&iScansNegatively)) !=GRIB_SUCCESS)
+        return err;
+    if((err = grib_get_long_internal(h, salternativeRowScanning,&alternativeRowScanning)) !=GRIB_SUCCESS)
+        return err;
 
     /* See Wolfram MathWorld: http://mathworld.wolfram.com/LambertConformalConicProjection.html */
     latFirstInRadians = latFirstInDegrees * DEG2RAD;
@@ -219,12 +219,12 @@ static int init(grib_iterator* iter,grib_handle* h,grib_arguments* args)
     /* Allocate latitude and longitude arrays */
     self->lats = (double*)grib_context_malloc(h->context,iter->nv*sizeof(double));
     if (!self->lats) {
-        grib_context_log(h->context,GRIB_LOG_ERROR,	"unable to allocate %ld bytes",iter->nv*sizeof(double));
+        grib_context_log(h->context,GRIB_LOG_ERROR, "Unable to allocate %ld bytes",iter->nv*sizeof(double));
         return GRIB_OUT_OF_MEMORY;
     }
     self->lons = (double*)grib_context_malloc(h->context,iter->nv*sizeof(double));
     if (!self->lats) {
-        grib_context_log(h->context,GRIB_LOG_ERROR,	"unable to allocate %ld bytes",iter->nv*sizeof(double));
+        grib_context_log(h->context,GRIB_LOG_ERROR, "Unable to allocate %ld bytes",iter->nv*sizeof(double));
         return GRIB_OUT_OF_MEMORY;
     }
     lats=self->lats;
@@ -245,7 +245,7 @@ static int init(grib_iterator* iter,grib_handle* h,grib_arguments* args)
                 x = -x;
             }
 
-            angle = atan(x / tmp);
+            angle = atan2(x, tmp);
             rho = sqrt(x*x + tmp2);
             if (n <= 0) rho = -rho;
             lonDeg = LoVInDegrees + (angle/n) * RAD2DEG;
@@ -259,7 +259,7 @@ static int init(grib_iterator* iter,grib_handle* h,grib_arguments* args)
 
     iter->e = -1;
 
-    return ret;
+    return err;
 }
 
 static int destroy(grib_iterator* i)
